;; Generated package description from devdocs.el  -*- no-byte-compile: t -*-
(define-package "devdocs" "0.6.1.0.20251012.193924" "Emacs viewer for DevDocs" '((emacs "27.1") (compat "30.1")) :commit "330b46505363e7e735e10b4ecbb8c722c0bc7c46" :authors '(("Augusto Stoffel" . "arstoffel@gmail.com")) :maintainer '("Augusto Stoffel" . "arstoffel@gmail.com") :keywords '("help") :url "https://github.com/astoff/devdocs.el")
